==> Bundle-Modules-2006.0510.tar.gz: Bundle-Modules-2006.0510/Modules/Acme/Everything/Unique.pm <==
package Bundle::Modules::Acme::Everything::Unique;

$VERSION = 2006.0510; ## (YYYY.MMDD)

1;

__END__

=head1 NAME

Bundle::Modules::Acme::Everything::Unique - All current unique modules in Bundle::Everything from CPAN

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::Modules::Acme::Everything::Unique'>

C<cpan -i Bundle::Modules::Acme::Everything::Unique>

=head1 CONTENTS
HtDig::Htsearch
WING
Class::PublicInternal
Net::IPP
VMS::User
CGI::FormManager
Filesys::mntent
Apache::Sybase::DBlib
Text::Wrap::Hyphenate
ERG
Fame
Exporter::Import
Getopt::Help
NexTrieve::Docseq
MSSQL::Sqllib
Apache2::PageKit
Python::Err
GSS
Mail::Maildir
GISI
File::sudoers
Frontier::RPC
WWW::Mail::Hotmail
ElectricArc
Remedy::AR
BoxBackup
AFS
NexTrieve::MIME
Proc::ExitStatus
RPM::Headers
Attribute::Abstract
Apache::AuthenDBI
Lemonldap::Portal
Games::Go::GoPair
Text::Parser
Bio::Affymetrix
HPUX::Ioscan
Astro::SkyCoords
Chatbot::RiveScript
W3C::LinkChecker
DBIx::SchemaView
Filesys::statfs
NexTrieve::Overview
Apache::LowerCaseGETs
Class::Eroot
Parse::YALALR
NexTrieve::Hitlist::Hit
SICStus
Apache::Safe
Event::tcp
Business::OnlinePayment::Cybersource
CGI::FormFactory
Mail::Vacation::LDAP
EventServer::Functions
Mono
Plugin::Language::DML
Getopt::Gnu
AI::Categorize
WWW::ShopBot
Apache::Upload
Apache::AddrMunge
Text::Substitute
EventServer::Gettimeofday
MIME::Latin1
NexTrieve::Message
NexTrieve::PDF
VMS::Misc
EventServer::Signal
RFID::EPC
Data::FormValidator::Upload
ControlX10::CM10
DBD::Recall
IO::Filter
Text::Bib
Thread::Group
NexTrieve::RFC822
Apache::Timeit
PDF::PlainLayout
OpenCA
Apache::AccessLimitNum
CGI::DBTables
CGI::Request
GISI::SHAPE
Mobile::WURFL
Class::Holon
VMS::System
DBD::RDB
NexTrieve::Collection::Index
NexTrieve::Daemon
File::Atomic
Win32::FileType
Image::ASCII
CGI::Base
Apache::Htaccess
Text::Stem
Math::Matrix::SVD
Win32::AdminMisc
SIL::Shoe
Crypt::ElGamal
Filesys::dfent
Crypt::Camellia
NexTrieve::Index
Apache::AuthenRaduis
Win32::GD
Sort::PolySort
ReleaseAction
Exporter::Options
VMS::Device
Finance::Bank::Commonwealth
SVN::Look
Watchdog::Service
Neural
Apache::Log::Spread
MIME::IO
CGI::SimpleCache
MARC
Win32::ODBC
Tk::FlatCheckbox
Python
Apache::AdBlocker
Business::OnlinePayment::Moneris
MMDS
Tk::Statusbar
Date:Jalali
HTML::BarChart
AFS::Command
BnP
Crypt::Schnorr::AuthSign
Protect
PostScript::Basic
Tree::Menu
Devel::PerlySense
VMS::Priv
Mail::MH
SOOP
CGI::Query
HTML::Info
Smirch
Apache::LogMail
Apache::BlockAgent
Bio::SAGE
Synergy
FameHLI
Win32::GUID
NexTrieve::UTF8
Sys::Sysconf
SMIMEUtil
Physics::Solar::VSO
Math::Interpolate
DBA::Backup
WWW::Search::Excite
Lingua::EN::Cardinal
JUNOS
PDF::Template
CGI::WebApp
Watchdog::HTTPService
Tie::Assert
Religion::Package
CORBA::XPIDL
Geo::Projection
VMS::Persona
Apache::AuthzGender
Net::USPS
VMS::Fileutils::SafeName
Apache::TicketAccess
Math::Nocarry
Object::Info
Concurrent
WebService::BabelFish
Getopt::EvaP
Tie::Plural::Scalar
POE::Session::GladeXML
Parse::Lexer
HTML::Demoroniser
NexTrieve::Collection
NexTrieve::Querylog
Lexical::Typeglob
Proxy::Tk
File::MultiTail
Palm::Magellan::NavCompanion
RFID::Matrics
VMS::Queue
Tie::Array::Huge
Apache::Checksum
Watchdog::MysqlService
Fortran::NameList
Class::TOM
Archive::Cabinet
Hardware::Simulator
Time:Compare
SVG::Template
Proc::PID::File::Fcntl
Apache::ModBT
SQL::QueryBroker
WWW::Webjay
Finance::Bank::DE::SpardaBank
CfgTie
Apache::AuthzSSL
CORBA::Python
HTML::Widgets::DateEntry
WWW::Lunarstorm
Ratpoison
Apache::Forward
IPC::Shm::Simple
Module::MakeDist
PDL::Slatec
Find::File::Object
Clips
PDA::Pilot
Archive::Tar::Stream
Test::Litmus
HtDig
HTML::Stripper
Mail::DSN
DCE::RPC
Finance::Shares::Chart
NexTrieve::DBI
Mail::Vacation
X11::Xforms
WWW::Scrobbler::Stats
Scalar::Footnote
Gemstone
Slash
Math::Geometry
Apache::AnonProxy
Term::Size::Heuristic
News::Search
Text::Wigwam
Log::Check
Win32::FUtils
Convert::Lucene
NexTrieve::Replay
Openview::Message
AI::NeuralNet
Quiz::Question
ex::caution
PixDraw
Win32::MSI
String::Ruby
Tk::DBIx
Persistence::Object
Time::JulianDateTime
Convert::Base
Apache::Magick
Apache::Servlet
Devel::Trampoline
SQL::Builder
Chart::Pie3d
Exporter::PkgAlias
Apache::AuthzAge
Interface::Param
CMS::Mediawiki
Crypt::OpenSSL::BN
Getopt::Long::File
PDL::IO::HDF5
RT
Apache::MimeDBI
VMS::Process
VMS::ICC
Net::Mac::Vendor
RFID::Base
POE::Component::MPG123
Datascope
NexTrieve::Document
Verilog::GetInfo
PDL::NetCDF
Apache::AuthNISPlus
Apache::DayLimit
XML::Validator::RelaxNG
Gtk::Dialog
BizTalk
Search::Kinosearch
Oracle::OCI
GD::Gauge
NexTrieve::Search
UUID
Devel::Truth_Table
Lingua::FeatureSet
Device::SerialPort::Xmodem
CGI::CList
Bio::Genex
NexTrieve
Pod::MIF
Font::TTF
Apache::Command
Apache::Handler
Boulder
IO::Redirect
XML
NexTrieve::Resource
App::Config
GISI::MIFMID
VMS::Monitor
HTML::Debug
Apache::StripSession
Regexp::Func
Business::OnlinePayment::E2Payments
PerlPoint::Package
Win32::Message
Win32::IIS:SMTP
Tie::RndHash
Oak
Orac
DBIx::TableAdapter
Apache::PATCH
Widget::FixedWidthFont::Input
GD::Barcode::Code93
NexTrieve::Targz
Class::Flyweight
Apache::AuthzDBI
Apache::WDB
WWW::TVguide::NL
Genezzo
Business::Payroll::AU::PAYG
SQL::Routine
DBIx::XMLMEssage
Fax::DataFax
Tk::Autoscroll
Mac::Spotlight
WWW::Search::Magellan
Logfile
Math::SimpleInterest
MSDOS::SysCalls
Apache2::DBI
PGP
Net::DHCP
NexTrieve::Mbox
Apache::SawAmpersand
Math::FresnalZone
HTML::Formulate
Archive::Parity
NetCDF
Authorizenet
PerlMenu
Apache::MsqlProxy
Lingua::PT
WIN32::MSI::SummaryInfo
WWW::Lyrics
PostScript::Barcode
DBD::Altera
Solaris::PerlGcc
Tern::Size::Heuristic
NexTrieve::Query
Language::VBParser
Apache::NavBar
PDF::Report::Table
CGI::Session::Encrypted
Template::TagParser
FileSys::Tree
Win32::Perfmon
MOP
Tk::SignOnDialog
Bleach
VMS::smg
Glade
CGI::MiniSvr
Config::Ini
Unix::UserAdmin
ToolTalk
Lingua::EN::Ordinal
Tie::WarnGlobal
Apache::MimeXML
RTF::Generator
Devel::DebugAPI
PHP::MySQL_Session
X11::Toolkit
Zeta
MSSQL::DBlib
Proc::times
Data::Dumper::HTML
Ioctl
X11::XRT
Perl6::Doc
Lemonolap
ePortal
NexTrieve::Hitlist
GSM::SMS
File::Size
IPC::UPDmsg
Tree::List2Tree
Image::Magick::BarChart
Algorithm::Munkre
Text::Banner
LockFile::Scheme
Win32::Pipe
SGML::SPGrove
Chart::Gdchart
XMLI
DBD::FreeTDS
PDL::LAPACK
Apache::AuthAny
Tk::Multi
Tk::Olwm
Cz::Speak
Carp::CheckArgs
File::Data
Apache::QuickCMS
RFID::Alien
Apache::DCELogin
DBD::SQLrelay
Net::ICAP
Finance::Shares::MySQL
Tk::ReportBox
Data::Stash
Math::BigIntFast
File::ManualFlock
Splash::DB
Linksys::Config
xDash
Mail::vpopmaild
DBD::Google
Tk::PhotoRotate
Apache::MIME
VMS::Fileutils::Root
Tie::Mem
DBA::Backup::mysql
Tk::ImageButton
Apache::SpeedLimit
Array::Reform
TeX::Convert::Image
NexTrieve::HTML
Apache::AxKit
Tie::PerfectHash
Sparky
CGI::BasePlus
Mac::Serial
=head1 CHANGES

=over 4

=item 0.01

This is Bundle::Modules::Acme::Everything::Unique initial version 2006.0510 (YYYY.MMDD)

This C<Bundle::Modules> component package is in pre-alpha state with hash ordering.

The ordering of listed modules will eventually be prioritized for efficiency and completeness.

Modules commented out of this module list are either unstable or stable in the C<Bundle::Modules> context.

Optimistically, if there are a lot of the modules commented out, then they are stable, and we're listing unstable context.

Optimistically, if there are a few of the modules commented out, then they are unstable, and we're listing stable context.

=back

=head1 AUTHOR

Eric R. Meyers (CPAN author/id/E/ER/ERMEYERS/Bundle-Modules-2006.0510)

==> Bundle-Modules-2006.0511.tar.gz: Bundle-Modules-2006.0511/Modules/Acme/Everything/Unique.pm <==
package Bundle::Modules::Acme::Everything::Unique;

$VERSION = 2006.0511; ## (YYYY.MMDD)

1;

__END__

=head1 NAME

=over

=item Bundle::Modules::Acme::Everything::Unique

All current I<stable> and I<unique> modules in Bundle::Modules::Acme::Everything

=back

=head1 SYNOPSIS

=over

=item C<% B<perl -MCPAN -e 'install Bundle::Modules::Acme::Everything::Unique'>>

=item C<% B<cpan -i Bundle::Modules::Acme::Everything::Unique>>

=back

=head1 CONTENTS

Finance::Bank::Commonwealth
Search::Kinosearch
HtDig::Htsearch
SVN::Look
Watchdog::Service
MSSQL::DBlib
WWW::Scrobbler::Stats
WING
Neural
Class::PublicInternal
Apache::Log::Spread
Plugin::Language::DML
WebService::BabelFish
Proc::times
MIME::IO
Scalar::Footnote
Data::Dumper::HTML
MSDOS::SysCalls
Oracle::OCI
Apache2::DBI
Getopt::EvaP
GD::Gauge
PGP
NexTrieve::Search
AI::Categorize
Getopt::Gnu
Ioctl
UUID
Net::IPP
X11::XRT
Net::DHCP
VMS::User
Perl6::Doc
Devel::Truth_Table
Gemstone
CGI::FormManager
Lingua::FeatureSet
Device::SerialPort::Xmodem
CGI::CList
WWW::ShopBot
Tie::Plural::Scalar
CGI::SimpleCache
MARC
Filesys::mntent
Lemonolap
NexTrieve::Mbox
Bio::Genex
Apache::Sybase::DBlib
Slash
Apache::SawAmpersand
POE::Session::GladeXML
Math::FresnalZone
Text::Wrap::Hyphenate
HTML::Formulate
ERG
Math::Geometry
Win32::ODBC
ePortal
Apache::AnonProxy
Archive::Parity
NexTrieve::Hitlist
Fame
NexTrieve
NetCDF
Authorizenet
Term::Size::Heuristic
Parse::Lexer
Pod::MIF
PerlMenu
Exporter::Import
Apache::Upload
News::Search
HTML::Demoroniser
NexTrieve::Collection
NexTrieve::Querylog
Tk::FlatCheckbox
Lexical::Typeglob
Font::TTF
Apache::MsqlProxy
Apache::Command
Apache::Handler
GSM::SMS
Proxy::Tk
Python
Boulder
Apache::AdBlocker
File::Size
File::MultiTail
Business::OnlinePayment::Moneris
Getopt::Help
NexTrieve::Docseq
Apache::AddrMunge
Text::Wigwam
Text::Substitute
Log::Check
Palm::Magellan::NavCompanion
EventServer::Gettimeofday
IO::Redirect
RFID::Matrics
MMDS
MIME::Latin1
MSSQL::Sqllib
Lingua::PT
Win32::FUtils
IPC::UPDmsg
Convert::Lucene
Tree::List2Tree
Image::Magick::BarChart
NexTrieve::Message
WIN32::MSI::SummaryInfo
VMS::Queue
Algorithm::Munkre
WWW::Lyrics
PostScript::Barcode
NexTrieve::Replay
Text::Banner
LockFile::Scheme
Tk::Statusbar
Tie::Array::Huge
Apache2::PageKit
DBD::Altera
XML
Openview::Message
Python::Err
AI::NeuralNet
Date:Jalali
Quiz::Question
NexTrieve::PDF
GSS
VMS::Misc
Win32::Pipe
Solaris::PerlGcc
HTML::BarChart
NexTrieve::Resource
Apache::Checksum
SGML::SPGrove
EventServer::Signal
RFID::EPC
AFS::Command
BnP
Chart::Gdchart
App::Config
ex::caution
PixDraw
ControlX10::CM10
Data::FormValidator::Upload
XMLI
Mail::Maildir
DBD::Recall
Crypt::Schnorr::AuthSign
Win32::MSI
IO::Filter
GISI::MIFMID
VMS::Monitor
Protect
HTML::Debug
PostScript::Basic
DBD::FreeTDS
Apache::StripSession
GISI
String::Ruby
Tern::Size::Heuristic
Regexp::Func
Business::OnlinePayment::E2Payments
NexTrieve::Query
PDL::LAPACK
Apache::AuthAny
PerlPoint::Package
Tree::Menu
Devel::PerlySense
Watchdog::MysqlService
Tk::DBIx
Text::Bib
VMS::Priv
Language::VBParser
Win32::Message
Win32::IIS:SMTP
File::sudoers
Tk::Multi
Thread::Group
Tie::RndHash
Frontier::RPC
Apache::NavBar
Persistence::Object
PDF::Report::Table
Tk::Olwm
Time::JulianDateTime
WWW::Mail::Hotmail
Oak
Convert::Base
Fortran::NameList
ElectricArc
NexTrieve::RFC822
Apache::Timeit
Cz::Speak
Orac
Mail::MH
OpenCA
PDF::PlainLayout
Class::TOM
CGI::Session::Encrypted
BoxBackup
Remedy::AR
Carp::CheckArgs
Archive::Cabinet
Template::TagParser
Apache::AccessLimitNum
Hardware::Simulator
AFS
Time:Compare
Apache::Magick
File::Data
FileSys::Tree
NexTrieve::MIME
Proc::ExitStatus
DBIx::TableAdapter
SOOP
RPM::Headers
Attribute::Abstract
Apache::PATCH
SVG::Template
Apache::QuickCMS
Apache::Servlet
Win32::Perfmon
MOP
CGI::Query
Proc::PID::File::Fcntl
Apache::ModBT
RFID::Alien
Apache::DCELogin
SQL::QueryBroker
Devel::Trampoline
DBD::SQLrelay
WWW::Webjay
SQL::Builder
Chart::Pie3d
HTML::Info
Net::ICAP
Widget::FixedWidthFont::Input
Apache::AuthenDBI
GD::Barcode::Code93
Exporter::PkgAlias
Tk::SignOnDialog
CGI::Request
CGI::DBTables
GISI::SHAPE
Smirch
Finance::Bank::DE::SpardaBank
Games::Go::GoPair
Lemonldap::Portal
CfgTie
Apache::AuthzAge
Finance::Shares::MySQL
NexTrieve::Targz
Bio::SAGE
Apache::BlockAgent
Apache::LogMail
Text::Parser
Synergy
FameHLI
Bio::Affymetrix
Apache::AuthzSSL
Tk::ReportBox
Win32::GUID
CORBA::Python
Data::Stash
HPUX::Ioscan
Astro::SkyCoords
Math::BigIntFast
Bleach
Class::Flyweight
NexTrieve::UTF8
Apache::AuthzDBI
Interface::Param
Apache::WDB
Chatbot::RiveScript
W3C::LinkChecker
HTML::Widgets::DateEntry
Mobile::WURFL
DBIx::SchemaView
WWW::TVguide::NL
Sys::Sysconf
Filesys::statfs
File::ManualFlock
NexTrieve::Overview
SMIMEUtil
Class::Holon
Apache::LowerCaseGETs
WWW::Lunarstorm
CMS::Mediawiki
VMS::System
Physics::Solar::VSO
VMS::smg
Math::Interpolate
Crypt::OpenSSL::BN
Class::Eroot
Getopt::Long::File
Parse::YALALR
NexTrieve::Hitlist::Hit
DBD::RDB
NexTrieve::Collection::Index
Splash::DB
NexTrieve::Daemon
DBA::Backup
Glade
PDL::IO::HDF5
CGI::MiniSvr
Ratpoison
Genezzo
Linksys::Config
RT
SICStus
Apache::MimeDBI
xDash
Mail::vpopmaild
VMS::Process
WWW::Search::Excite
File::Atomic
Business::Payroll::AU::PAYG
VMS::ICC
Lingua::EN::Cardinal
SQL::Routine
Win32::FileType
Net::Mac::Vendor
Image::ASCII
Apache::Safe
JUNOS
CGI::Base
DBD::Google
RFID::Base
Apache::Forward
Config::Ini
Unix::UserAdmin
IPC::Shm::Simple
PDF::Template
Tk::PhotoRotate
Apache::MIME
DBIx::XMLMEssage
Fax::DataFax
Module::MakeDist
Tk::Autoscroll
Apache::Htaccess
PDL::Slatec
ToolTalk
Text::Stem
Find::File::Object
VMS::Fileutils::Root
Clips
Tie::Mem
Archive::Tar::Stream
PDA::Pilot
Test::Litmus
Math::Matrix::SVD
Win32::AdminMisc
CGI::WebApp
HTML::Stripper
HtDig
SIL::Shoe
Mac::Spotlight
DBA::Backup::mysql
Watchdog::HTTPService
WWW::Search::Magellan
Tk::ImageButton
Crypt::ElGamal
Event::tcp
Lingua::EN::Ordinal
Filesys::dfent
Crypt::Camellia
Logfile
Business::OnlinePayment::Cybersource
Tie::Assert
Mail::DSN
CORBA::XPIDL
Religion::Package
DCE::RPC
Apache::SpeedLimit
Finance::Shares::Chart
Geo::Projection
CGI::FormFactory
Array::Reform
POE::Component::MPG123
Tie::WarnGlobal
TeX::Convert::Image
NexTrieve::Index
Datascope
VMS::Persona
NexTrieve::Document
Verilog::GetInfo
Mail::Vacation::LDAP
NexTrieve::DBI
Apache::MimeXML
PDL::NetCDF
Apache::AuthNISPlus
EventServer::Functions
Apache::DayLimit
RTF::Generator
Apache::AuthenRaduis
Apache::AuthzGender
XML::Validator::RelaxNG
NexTrieve::HTML
Gtk::Dialog
Devel::DebugAPI
Net::USPS
Apache::AxKit
Win32::GD
VMS::Fileutils::SafeName
BizTalk
Mail::Vacation
Tie::PerfectHash
Sort::PolySort
Sparky
PHP::MySQL_Session
Apache::TicketAccess
X11::Toolkit
ReleaseAction
Math::SimpleInterest
Math::Nocarry
CGI::BasePlus
Mac::Serial
Zeta
Object::Info
X11::Xforms
Exporter::Options
Concurrent
VMS::Device
Mono

=head1 CHANGES

=over

=item 2006.0510 (YYYY.MMDD)

Initial version of: Bundle::Modules::Acme::Everything::Unique-2006.0510

This B<L<Bundle::Modules>> component package is in pre-alpha state with hash ordering.

The ordering of listed modules will eventually be prioritized for efficiency and completeness.

Modules commented out of this module list are either I<unstable> or I<stable> in the B<L<Bundle::Modules>> context.

Optimistically, if there are a lot of the modules commented out, then they are I<stable>, and we're listing I<unstable> context.

Optimistically, if there are a few of the modules commented out, then they are I<unstable>, and we're listing I<stable> context.

If you use the command C<B<man Bundle::Modules::Acme::Everything::Unique>>, type C<B</#>> to see the commented out modules as they're higlighted for you by B<L<man>>.

=back

=head1 DESCRIPTION

=over

=item This Bundle package will install all of the modules listed, if they're not commented out of the B<L<Bundle::Modules>> context.

=back

=head1 SEE ALSO

=over

=item I<L<Bundle::Modules::Unstable>>, I<L<Bundle::Modules::CPAN>>, I<L<Bundle::Modules::CPAN::Unstable>>, I<L<Bundle::Modules::Acme::Everything>>, I<L<Bundle::Modules::Acme::Everything::Unstable>>, I<L<Bundle::Modules::Acme::Everything::Unique>>, I<L<Bundle::Modules::Acme::Everything::Unique::Unstable>>

=back

=head1 AUTHORS

=over

=item Eric R. Meyers E<lt>ermeyers@adelphia.netE<gt>

=back

=head1 LICENSE for http://www.cpan.org/modules/by-authors/id/E/ER/ERMEYERS/Bundle-Modules-2006.0511

=over

=item http://www.perl.com/perl/misc/Artistic.html

=item This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

=back

=head1 COPYRIGHT

=over

=item Copyright 2006 by Eric R. Meyers E<lt>ermeyers@adelphia.netE<gt>

=back
